@@ -91,7 +91,7 @@ def keygetter(
                 dct = getattr(dct, sub_field)
     except Exception as e:
         traceback.print_stack()
-        logger.debug(f"The above error was {e}")
+        logger.debug("The above error was %s", e)
         return None
     return dct
 
@@ -122,12 +122,12 @@ def parse_lookup(obj: Mapping[str, t.Any], path: str, lookup: str) -> t.Any | No
     """
     try:
         if isinstance(path, str) and isinstance(lookup, str) and path.endswith(lookup):
-            field_name = path.rsplit(lookup)[0]
+            field_name = path.split(lookup, maxsplit=1)[0]
             if field_name is not None:
                 return keygetter(obj, field_name)
     except Exception as e:
         traceback.print_stack()
-        logger.debug(f"The above error was {e}")
+        logger.debug("The above error was %s", e)
     return None
 
 
@@ -489,7 +489,7 @@ class QueryList(list[T], t.Generic[T]):
             return False
 
         if len(self) == len(data):
-            for a, b in zip(self, data):
+            for a, b in zip(self, data, strict=False):
                 if isinstance(a, Mapping):
                     a_keys = a.keys()
                     if a.keys == b.keys():
